
# Slot: sequence variant qualifier


a qualifier used in an association with the variant

URI: [biolink:sequence_variant_qualifier](https://w3id.org/biolink/vocab/sequence_variant_qualifier)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [SequenceVariant](SequenceVariant.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [GeneHasVariantThatContributesToDiseaseAssociation](GeneHasVariantThatContributesToDiseaseAssociation.md)
